Models
======


******************************************
Observation Records vs. Observation Groups
******************************************
In the TOM Toolkit, `Observation Records` represent the details of an individual observation as submitted to the
observatory. This is what will be updated with a new status as the observation is completed.

`Observation Groups` are any arbitrary collection of observations that might be related to each other in some way.
This might be everything observed on a certain night, everything observed by a single user, or some other science-based
grouping.

.. automodule:: tom_observations.models
    :members: